<?php

namespace Drupal\content_fixtures\Fixture;

use Drupal\content_fixtures\Service\ReferenceRepositoryInterface;

abstract class AbstractFixture implements SharedFixtureInterface {

  /**
   * Fixture reference repository.
   *
   * @var ReferenceRepositoryInterface
   */
  protected $referenceRepository;

  /**
   * @inheritdoc
   */
  public function setReferenceRepository(ReferenceRepositoryInterface $referenceRepository)
  {
      $this->referenceRepository = $referenceRepository;
  }

  /**
   * Set the reference entry identified by $name and referenced to managed
   * $object. If $name already is set, it overrides it.
   *
   * @param string $name
   * @param object $object
   *   Managed object.
   *
   * @see ReferenceRepositoryInterface::setReference
   *
   * @return void
   */
  public function setReference($name, $object)
  {
      $this->referenceRepository->setReference($name, $object);
  }

  /**
   * Set the reference entry identified by $name and referenced to managed
   * $object. If $name already is set, it throws a BadMethodCallException
   * exception.
   *
   * @param string $name
   * @param object $object
   *   Managed object.
   *
   * @see ReferenceRepositoryInterface::addReference
   *
   * @throws \BadMethodCallException
   *   If repository already hasa reference by $name.
   *
   * @return void
   */
  public function addReference($name, $object)
  {
      $this->referenceRepository->addReference($name, $object);
  }

  /**
   * Loads an object using stored reference
   * named by $name
   *
   * @param string $name
   *
   * @see ReferenceRepositoryInterface::getReference
   *
   * @return object
   */
  public function getReference($name)
  {
      return $this->referenceRepository->getReference($name);
  }

  /**
   * Check if an object is stored using reference
   * named by $name
   *
   * @param string $name
   *
   * @see ReferenceRepositoryInterface::hasReference
   *
   * @return boolean
   */
  public function hasReference($name)
  {
      return $this->referenceRepository->hasReference($name);
  }
}
